Learn R Programming

meedr (version 0.0.2)

get_monthly: Get data on monthly market expectations for economic indicators (Focus/BCB)

Description

This function provides the extraction of data and statistics related to expectations of economic indicators, specifically monthly market expectations, made available by the Central Bank of Brazil's Expectations System through the Olinda API. The data comes from several financial institutions: banks, funds, research houses, etc. Important: arguments are case sensitive.

Usage

get_monthly(
  indicator = NULL,
  first_date = Sys.Date() - 2 * 365,
  last_date = Sys.Date(),
  reference_date = NULL,
  be_quiet = FALSE,
  use_memoise = TRUE,
  do_parallel = FALSE
)

Arguments

indicator

A single string or a character vector with economic indicators names, see details for possible value. Defaults to NULL.

first_date

A single string or Date in "YYYY-mm-dd" format. Default for 2 years prior to the current date.

last_date

A single string or Date in "YYYY-mm-dd" format. Default is the current date.

reference_date

A single string in "mm/YYYY" format, indicating the reference month and year for which the statistic is expected. Defaults to NULL.

be_quiet

Logical. Should messages or warnings not be displayed? Defaults to FALSE.

use_memoise

Logical. Sets the use of caching system, creating a folder named "cache_bcb" by default. Default to TRUE.

do_parallel

Logical. For using parallel data importation. Defaults to FALSE.

Value

A tibble with data from BCB-Olinda Data Services.

Details

For periods for which there are no statistics, they will be omitted from the query.

Possible values for indicator argument: "IGP-DI", "IGP-M", "INPC", "IPA-DI", "IPA-M", "IPCA", "IPCA-15", "IPC-FIPE", "Produ<U+00E7><U+00E3>o industrial", "Meta para taxa over-selic", "Taxa de c<U+00E2>mbio".

Examples

Run this code
# NOT RUN {
df <- get_monthly(
  indicator = "IPCA",
  first_date = Sys.Date() - 30,
  reference_date = format(Sys.Date(), "%m/%Y"),
  use_memoise = FALSE
)
# }

Run the code above in your browser using DataLab